## 目標

確保 GitHub Copilot Chat 生成的代碼符合以下標準：

- **一致性**：與項目現有代碼風格保持一致。
- **可讀性**：代碼清晰、易於理解和維護。
- **效率**：高效執行，資源利用合理。
- **安全性**：避免常見的安全漏洞和風險。
- **可測試性**：易於編寫單元測試和集成測試。

## 代碼風格指導

### 語言與框架

- **語言**：JavaScript (ES6+) 等。
- **框架**：React、Node.js、Express、Mocha 等。

### 命名規則

- **變數與函數**：使用駝峰式命名法（e.g., `getUserData`）。
- **類與組件**：使用帕斯卡命名法（e.g., `UserService`）。
- **常量**：使用全大寫字母和下劃線分隔（e.g., `MAX_LIMIT`）。

### 格式化

- **縮進**：使用兩個空格或四個空格，根據項目設定。
- **行長**：保持每行不超過 80-100 個字符。
- **分號**：根據語言和項目規範使用或省略分號。

### 代碼結構

- **模組化**：將功能拆分為獨立的模組或組件。
- **單一職責原則**：每個函數或類只負責一個功能。
- **避免全局變量**：使用閉包或模組範圍來管理變量。

## 安全性考量

- **輸入驗證**：對所有外部輸入進行嚴格的驗證和消毒。
- **避免 SQL 注入**：使用 ORM 或參數化查詢。
- **敏感信息管理**：不在代碼中硬編碼敏感信息，使用環境變數管理。
- **錯誤處理**：避免泄露內部錯誤信息給用戶端。

## 性能優化

- **算法效率**：選擇適當的數據結構和算法以提升性能。
- **資源管理**：合理管理內存和資源，避免內存泄漏。
- **延遲加載**：對於大型模組或組件，實施按需加載策略。
- **緩存機制**：使用緩存來減少重複計算或請求。

## 測試要求

- **單元測試**：為每個功能單元編寫測試用例，確保其按預期工作。
- **集成測試**：測試模組之間的交互，確保系統整體協作正常。
- **測試覆蓋率**：目標覆蓋率應達到 80% 以上，具體根據項目需求調整。
- **自動化測試**：使用 CI/CD 工具自動運行測試，確保代碼變更不破壞現有功能。

## 文件與註釋

- **代碼註釋**：為複雜邏輯或關鍵部分添加註釋，解釋其用途和工作原理。
- **函數說明**：在每個函數或方法前添加簡要說明，包括參數和返回值。
- **README**：為每個模組或組件添加 README 文件，說明其功能和使用方法。
- **API 文檔**：使用工具生成或手動撰寫 API 文檔，詳細描述接口規範。

## 錯誤處理

- **一致的錯誤格式**：統一錯誤對象的結構，包含錯誤碼和描述。
- **捕獲異常**：使用 try-catch 塊捕獲異常，並進行適當處理。
- **日誌記錄**：將錯誤信息記錄到日誌系統，便於後續調試和監控。
- **用戶反饋**：提供友好的錯誤提示給用戶，避免泄露內部實現細節。